# Changelog
All notable changes to this project will be documented in this file. See [conventional commits](https://www.conventionalcommits.org/) for commit guidelines.

- - -
## v0.1.0 - 2024-10-01
#### Bug Fixes
- Always take measurement counts - (e3be3b2) - Julian Popescu
- require max iter - (9d29223) - Julian Popescu
- Fix quadratic constraint encoding - (8a0221d) - Julian Popescu
- Add extra validation for app decoding - (a955fcb) - Julian Popescu
- Change testing endpoint - (3c4a119) - Julian Popescu
- Make init params required - (969ebd5) - Julian Popescu
- only take unbound parameters for vqe - (7083d36) - Julian Popescu
- fix JSON type in API - (74b2794) - Julian Popescu
#### Continuous Integration
- Add cog setup - (b2d13fc) - Julian Popescu
- Add github workflow - (09e2390) - Julian Popescu
#### Documentation
- Add links and readme - (70fed91) - Julian Popescu
- Add basic docs - (ad1125d) - Julian Popescu
#### Features
- add all aer simulators to backend name - (c46df49) - Julian Popescu
- Add scaffolding for docs - (c2f62af) - Julian Popescu
- Add auto backend - (4a2da6d) - Julian Popescu
- Add all backend options - (50e45e9) - Julian Popescu
- Add backend to run_options - (0a98402) - Julian Popescu
- Add some helper functions - (610572e) - Julian Popescu
- add maxcut - (8eedc42) - Julian Popescu
- Add measurment counts to VQE results - (457835f) - Julian Popescu
- add apps - (4eb2eb7) - Julian Popescu
- Add sampler data to VQE results - (605fbc4) - Julian Popescu
- Add a callable interface to ansatz for VQE and halt reason - (4519f1c) - Julian Popescu
- Add quadratic program - (a96a1b0) - Julian Popescu
- create client - (e5c20ee) - Julian Popescu
- Encoding and decoding primitives - (782f014) - Julian Popescu
#### Miscellaneous Chores
- init - (e9020f1) - Julian Popescu
#### Refactoring
- Don't use JSON stringify for observables - (07d7e95) - Julian Popescu
- Add quadratic problems from qiskit optimization and put encoding into submodules - (2a7330b) - Julian Popescu
- rearrange API to make more convenient and allow running locally - (75389f3) - Julian Popescu
- rename - (e459c32) - Julian Popescu
#### Tests
- Add test for scaleway - (9ee5363) - Julian Popescu

- - -

Changelog generated by [cocogitto](https://github.com/cocogitto/cocogitto).